pub struct Video { /* private fields */ }Expand description
A YouTube downloader, which allows you to download all available formats and qualities of a YouTube video.
Each instance of Video represents an existing, available, and downloadable
video.
There are two ways of constructing an instance of Video:
- By using the asynchronous
Video::from_*methods. These methods will take some kind of video-identifier, like anUrlor anId, will then internally download the necessary video information and finally descramble it. - By calling
VideoDescrambler::descramble. Since aVideoDescrambleralready contains the necessary video information, and just need to descramble it, no requests are performed. (This gives you more control over the process).
Examples
- Constructing using
Video::from_url(orVideo::from_id) (easiest way)
let url = Url::parse("https://youtube.com/watch?iv=5jlI4uzZGjU")?;
let video: Video = Video::from_url(&url).await?;- Constructing using
VideoDescrambler::descramble
let url = Url::parse("https://youtube.com/watch?iv=5jlI4uzZGjU")?;
let fetcher: VideoFetcher = VideoFetcher::from_url(&url)?;
let descrambler: VideoDescrambler = fetcher.fetch().await?;
let video: Video = descrambler.descramble()?;- Construction using chained calls
let url = Url::parse("https://youtube.com/watch?iv=5jlI4uzZGjU")?;
let video: Video = VideoFetcher::from_url(&url)?
.fetch()
.await?
.descramble()?;- Downloading a video using an existing
Videoinstance
let video_path = video
.streams()
.iter()
.filter(|stream| stream.includes_video_track && stream.includes_audio_track)
.max_by_key(|stream| stream.quality_label)
.unwrap()
.download()
.await?;Implementations
Sourceimpl Video
impl Video
Sourcepub async fn from_url(url: &Url) -> Result<Self>
pub async fn from_url(url: &Url) -> Result<Self>
Errors
- When
VideoFetcher::from_urlfails. - When
VideoFetcher::fetchfails. - When
VideoDescrambler::descramblefails.
Sourcepub async fn from_id(id: IdBuf) -> Result<Self>
pub async fn from_id(id: IdBuf) -> Result<Self>
Errors
- When
VideoFetcher::fetchfails. - When
VideoDescrambler::descramblefails.
Sourcepub fn video_info(&self) -> &VideoInfo
pub fn video_info(&self) -> &VideoInfo
The VideoInfo of the video.
Sourcepub fn into_streams(self) -> Vec<Stream>
pub fn into_streams(self) -> Vec<Stream>
Takes all Streams of the video.
Sourcepub fn into_parts(self) -> (VideoInfo, Vec<Stream>)
pub fn into_parts(self) -> (VideoInfo, Vec<Stream>)
Decomposes a Video into it’s raw parts.
Sourcepub fn video_details(&self) -> Arc<VideoDetails>
pub fn video_details(&self) -> Arc<VideoDetails>
The VideoDetailss of the video.
Sourcepub fn is_age_restricted(&self) -> bool
pub fn is_age_restricted(&self) -> bool
Whether or not the video is age restricted.
Sourcepub fn best_quality(&self) -> Option<&Stream>
pub fn best_quality(&self) -> Option<&Stream>
The Stream with the best quality.
This stream is guaranteed to contain both a video as well as an audio track.
Sourcepub fn worst_quality(&self) -> Option<&Stream>
pub fn worst_quality(&self) -> Option<&Stream>
The Stream with the worst quality.
This stream is guaranteed to contain both a video as well as an audio track.
Sourcepub fn best_video(&self) -> Option<&Stream>
pub fn best_video(&self) -> Option<&Stream>
The Stream with the best video quality.
This stream is guaranteed to contain only a video but no audio track.
Sourcepub fn worst_video(&self) -> Option<&Stream>
pub fn worst_video(&self) -> Option<&Stream>
The Stream with the worst video quality.
This stream is guaranteed to contain only a video but no audio track.
Sourcepub fn best_audio(&self) -> Option<&Stream>
pub fn best_audio(&self) -> Option<&Stream>
The Stream with the best audio quality.
This stream is guaranteed to contain only a audio but no video track.
Sourcepub fn worst_audio(&self) -> Option<&Stream>
pub fn worst_audio(&self) -> Option<&Stream>
The Stream with the worst audio quality.
This stream is guaranteed to contain only a audio but no video track.